@@ -245,7 +245,7 @@ class GetLatestTinderbox(object):
 
             # determine which test logs to download
             if tests:
-              logs = dict([(test, value) for test.value in logs.items()
+              logs = dict([(test, value) for test, value in logs.items()
                            if test in tests])
 
             if logger:
